@@ -92,7 +92,7 @@ class XMLParseTest(unittest.TestCase):
         check = self._make_checker(guest)
 
         check("name", "TestGuest", "change_name")
-        check("description", None, "Hey desc changed")
+        check("description", None, "Hey desc changed&")
         check("maxvcpus", 5, 12)
         check("vcpus", 12, 10)
         check("cpuset", "1-3", "1-8,^6", "1-5,15")
@@ -160,6 +160,9 @@ class XMLParseTest(unittest.TestCase):
         check("memory_mode", "interleave", "strict", None)
         check("memory_nodeset", "1-5,^3,7", "2,4,6")
 
+        check = self._make_checker(guest.get_devices("memballoon")[0])
+        check("model", "virtio", "none")
+
         self._alter_compare(guest.get_config_xml(), outfile)
 
     def testAlterMinimalGuest(self):
@@ -387,7 +390,7 @@ class XMLParseTest(unittest.TestCase):
         check("model", None, "testmodel")
         check("bridge", None, "br0")
         check("network", None, "route")
-        check("macaddr", "11:11:11:11:11:11", "AA:AA:AA:AA:AA:AA")
+        check("macaddr", "22:11:11:11:11:11", "AA:AA:AA:AA:AA:AA")
         self.assertEquals(dev1.get_source(), None)
 
         check = self._make_checker(dev2)
@@ -547,10 +550,10 @@ class XMLParseTest(unittest.TestCase):
         check("type", "pci")
         check("managed", True, True)
         check("mode", "subsystem", "capabilities")
-        check("domain", "0x0", "0x2")
-        check("bus", "0x11", "0x99")
-        check("slot", "0x22", "0x88")
-        check("function", "0x33", "0x77")
+        check("domain", "0x0", "0x4")
+        check("bus", "0x1", "0x5")
+        check("slot", "0x2", "0x6")
+        check("function", "0x3", "0x7")
 
         self._alter_compare(guest.get_config_xml(), outfile)
 
